C
C LAST UPDATE:
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C******************************
C**     LFN_GET_PROFPARS     **
C******************************
C
CD-Routine: Get Profile Parameters - LFN_GET_PROFPARS
C This routine is used to return details of the profile parameters calculated
C by a profile determining pass of the routine LFN_SAINT.
CD-end
CD-Fortran:
      SUBROUTINE LFN_GET_PROFPARS (IPK, IPL, NP_HALF, NUMP, NUMBIN,
     +                             PROF_ROT)
CD-end
      INCLUDE 'implicit_none.finc'
C
C PURPOSE: Get profile details for sprofile calculated by LFN_SAINT
C 
C AUTHOR: J.W. Campbell 
C
C ARGUMENTS:
C
      INTEGER IPK
      INTEGER IPL
      INTEGER NP_HALF
      INTEGER NUMP
      INTEGER NUMBIN
      LOGICAL PROF_ROT
CD-Parameters:
C   IPK                 i  (W) Pack no. used in profiles calculation
C   IPL                 i  (W) Plate no. used in profiles calculation
C   NP_HALF             i  (W) Half size of box used in profiles 
C                              calculation (box 2*NP_HALF+1 square)
C   NUMP                i  (W) No. of pixels used in profiles
C   NUMBIN              i  (W) No. of profile bins
C   PROF_ROT            l  (W) Profiles rotated flag
CD-end
C
C====== Parameter statements
C 
      INCLUDE 'saint_limits.finc'
C
C====== GLOBALS:
C
      INCLUDE 'lfn_saint.finc'
C
C====== LOCALS:
C
      INTEGER I
      INTEGER IX
      INTEGER IY
      INTEGER IHALF

C     INTEGER I       !Temp/loop variable
C     INTEGER IX      !Loop over 'x' pixels (offsets)
C     INTEGER IY      !Loop over 'y' pixels (offsets)
C     INTEGER IHALF   !Half size of index array

C
C------------------------------------------------------------------------------- 
C
      IPK = IPROF_PK
      IPL = IPROF_PL
      NP_HALF = NPR_HALF
      NUMP = NUM_IN_PROF
      NUMBIN = NPROF_BIN
      PROF_ROT = PROF_ROTATE
      RETURN
      END
